==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/IntegrationRuntimeCustomSetupScriptPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.IntegrationRuntimeCustomSetupScriptPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Custom setup script properties for a managed dedicated integration runtime.
 * @property blobContainerUri The URI of the Azure blob container that contains the custom setup script.
 * @property sasToken The SAS token of the Azure blob container.
 */
public data class IntegrationRuntimeCustomSetupScriptPropertiesArgs(
    public val blobContainerUri: Output<String>? = null,
    public val sasToken: Output<SecureStringArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.IntegrationRuntimeCustomSetupScriptPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.synapse.inputs.IntegrationRuntimeCustomSetupScriptPropertiesArgs =
        com.pulumi.azurenative.synapse.inputs.IntegrationRuntimeCustomSetupScriptPropertiesArgs.builder()
            .blobContainerUri(blobContainerUri?.applyValue({ args0 -> args0 }))
            .sasToken(sasToken?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [IntegrationRuntimeCustomSetupScriptPropertiesArgs].
 */
@PulumiTagMarker
public class IntegrationRuntimeCustomSetupScriptPropertiesArgsBuilder internal constructor() {
    private var blobContainerUri: Output<String>? = null

    private var sasToken: Output<SecureStringArgs>? = null

    /**
     * @param value The URI of the Azure blob container that contains the custom setup script.
     */
    @JvmName("ewyhslmsclcbocjh")
    public suspend fun blobContainerUri(`value`: Output<String>) {
        this.blobContainerUri = value
    }

    /**
     * @param value The SAS token of the Azure blob container.
     */
    @JvmName("ghtedniaokqmnqhy")
    public suspend fun sasToken(`value`: Output<SecureStringArgs>) {
        this.sasToken = value
    }

    /**
     * @param value The URI of the Azure blob container that contains the custom setup script.
     */
    @JvmName("wasknximtruvakjt")
    public suspend fun blobContainerUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.blobContainerUri = mapped
    }

    /**
     * @param value The SAS token of the Azure blob container.
     */
    @JvmName("wsoatfaruiqxgmvx")
    public suspend fun sasToken(`value`: SecureStringArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sasToken = mapped
    }

    /**
     * @param argument The SAS token of the Azure blob container.
     */
    @JvmName("kmpdhjxafbyiqpin")
    public suspend fun sasToken(argument: suspend SecureStringArgsBuilder.() -> Unit) {
        val toBeMapped = SecureStringArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sasToken = mapped
    }

    internal fun build(): IntegrationRuntimeCustomSetupScriptPropertiesArgs =
        IntegrationRuntimeCustomSetupScriptPropertiesArgs(
            blobContainerUri = blobContainerUri,
            sasToken = sasToken,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/IntegrationRuntimeCustomSetupScriptPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.IntegrationRuntimeCustomSetupScriptPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Custom setup script properties for a managed dedicated integration runtime.
 * @property blobContainerUri The URI of the Azure blob container that contains the custom setup script.
 * @property sasToken The SAS token of the Azure blob container.
 */
public data class IntegrationRuntimeCustomSetupScriptPropertiesArgs(
    public val blobContainerUri: Output<String>? = null,
    public val sasToken: Output<SecureStringArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.IntegrationRuntimeCustomSetupScriptPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.synapse.inputs.IntegrationRuntimeCustomSetupScriptPropertiesArgs =
        com.pulumi.azurenative.synapse.inputs.IntegrationRuntimeCustomSetupScriptPropertiesArgs.builder()
            .blobContainerUri(blobContainerUri?.applyValue({ args0 -> args0 }))
            .sasToken(sasToken?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [IntegrationRuntimeCustomSetupScriptPropertiesArgs].
 */
@PulumiTagMarker
public class IntegrationRuntimeCustomSetupScriptPropertiesArgsBuilder internal constructor() {
    private var blobContainerUri: Output<String>? = null

    private var sasToken: Output<SecureStringArgs>? = null

    /**
     * @param value The URI of the Azure blob container that contains the custom setup script.
     */
    @JvmName("wokneqfwlkbhqnyw")
    public suspend fun blobContainerUri(`value`: Output<String>) {
        this.blobContainerUri = value
    }

    /**
     * @param value The SAS token of the Azure blob container.
     */
    @JvmName("ymowiyrynndoftfc")
    public suspend fun sasToken(`value`: Output<SecureStringArgs>) {
        this.sasToken = value
    }

    /**
     * @param value The URI of the Azure blob container that contains the custom setup script.
     */
    @JvmName("kgqmjfbnjeibdqhk")
    public suspend fun blobContainerUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.blobContainerUri = mapped
    }

    /**
     * @param value The SAS token of the Azure blob container.
     */
    @JvmName("ldinesgiypyufrrb")
    public suspend fun sasToken(`value`: SecureStringArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sasToken = mapped
    }

    /**
     * @param argument The SAS token of the Azure blob container.
     */
    @JvmName("dhltgvlggbbdoqhl")
    public suspend fun sasToken(argument: suspend SecureStringArgsBuilder.() -> Unit) {
        val toBeMapped = SecureStringArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sasToken = mapped
    }

    internal fun build(): IntegrationRuntimeCustomSetupScriptPropertiesArgs =
        IntegrationRuntimeCustomSetupScriptPropertiesArgs(
            blobContainerUri = blobContainerUri,
            sasToken = sasToken,
        )
}
